StagingCapture

Struct StagingCapture 

pub struct StagingCapture { /* private fields */ }
Cross-platform frame capture using GPU→CPU staging buffers.

Uses a ring of staging buffers to overlap capture of frame N with encoding of frame N-1 and rendering of frame N+1.

Implementations

Source

impl StagingCapture

pub fn new(ring_size: usize) -> Self

Create a new staging capture with the given number of ring buffers.